pyxmpp2.message

Package pyxmpp2 :: Module message |
[hide private]

# Module message

Message XMPP stanza handling

Normative reference:
  - RFC 3920

Classes | [hide private]
| Message <message /> stanza class.

Variables | [hide private]
| MESSAGE_TYPES = ``(``'``normal``'``,` `'``chat``'``,` `'``headline``'``,` `'``error``'``,` `'``group``...``

Variables Details | [hide private]

  ### MESSAGE_TYPES Value:
      ('normal', 'chat', 'headline', 'error', 'groupchat')